#
# spec file for package python-rtslib-fb
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif

%bcond_with common

%define dbdir %{_sysconfdir}/target
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-rtslib-fb
Version:        2.1.75
Release:        150600.12.2
Summary:        API for Linux kernel SCSI target (aka LIO)
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/open-iscsi/rtslib-fb.git
Source:         python-rtslib-fb-v%{version}.tar.xz
Patch2:         rtslib-Fix-handling-of-sysfs-RW-attrs-that-are-actually-RO.patch
Patch3:         rtslib-target-service-for-suse.patch
BuildRequires:  %{python_module pyudev}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros >= 20210929
Requires:       python-pyudev
%define oldpython python
%define cpkg %{oldpython}-rtslib-fb-common
%if %{with common}
Requires:       %{cpkg}
%else
Conflicts:      %{cpkg}
%endif
%if %{with libalternatives}
Requires:       alts
BuildRequires:  alts
%else
Requires(post): update-alternatives
Requires(postun):update-alternatives
%endif
Provides:       python-rtslib = %{version}-%{release}
Obsoletes:      python-rtslib < %{version}
BuildArch:      noarch

%python_subpackages

%description
rtslib-fb is an object-based Python library for configuring the LIO generic
SCSI target, present in 3.x Linux kernel versions. rtslib-fb is licensed under
the Apache 2.0 license. Contributions are welcome

%package -n %{cpkg}
Summary:        Common python-rtslib-fb subpackage for Python 2 or 3
Group:          Development/Languages/Python
Obsoletes:      %{name} < %{version}-%{release}

%description -n %{cpkg}
python-rtslib-fb-common is the invariant base package needed by both
python2-rtslib-fb and python3-rtslib-fb.

%prep
%setup -q -n python-rtslib-fb-v%{version}
%patch2 -p1
%patch3 -p1

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}/%{_bindir}/targetctl
%fdupes %{buildroot}
install -d -m755 %{buildroot}%{_mandir}/man5
install -m644 doc/saveconfig.json.5 %{buildroot}%{_mandir}/man5
install -d -m755 %{buildroot}%{_mandir}/man8
install -m644 doc/targetctl.8 %{buildroot}%{_mandir}/man8
install -d -m755 %{buildroot}/%{dbdir}
install -d -m755 %{buildroot}/%{dbdir}/pr
install -d -m755 %{buildroot}/%{dbdir}/alua
mkdir -p %{buildroot}/%{_unitdir}/
install -m644 systemd/target.service %{buildroot}/%{_unitdir}
install -d -m755 %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rctarget

%post
%python_install_alternative targetctl
%{service_add_post target.service}

%postun
%python_uninstall_alternative targetctl
%{service_del_postun target.service}

%pre
%{service_add_pre target.service}
# If libalternatives is used: Removing old update-alternatives entries.
%python_libalternatives_reset_alternative targetctl

%preun
%{stop_on_removal target}
%{service_del_preun target.service}

%if %{with common}
%post -n %{cpkg}
%{service_add_post target.service}

%postun -n %{cpkg}
%{service_del_postun target.service}

%pre -n %{cpkg}
%{service_add_pre target.service}

%preun -n %{cpkg}
%{service_del_preun target.service}
%endif

%files %{python_files}
%python_alternative %{_bindir}/targetctl
%{python_sitelib}/*

%if %{with common}
%files -n %{cpkg}
%endif
%license COPYING
%doc README.md
%dir %{dbdir}
%dir %{dbdir}/pr
%dir %{dbdir}/alua
%{_unitdir}/target.service
%{_sbindir}/rctarget
%doc %{_mandir}/man5/saveconfig.json.5.gz
%doc %{_mandir}/man8/targetctl.8.gz

%changelog
* Tue Jan  9 2024 ddiss@suse.com
- Drop downstream-only LIO target_core_rbd support (bsc#1218634)
  * rbd-support-disable_emulate_legacy_capacity.patch
  * rbd-support.patch
* Mon Jun  5 2023 daniel.garcia@suse.com
- Do not build python-rtslib-fb-common package
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Fri May  6 2022 lduncan@suse.com
- Update to version v2.1.75: (bsc#1206720)
  * version 2.1.75
  * rtslib: fix missing ':' after else statement
  * dbroot: let the user change the dbroot directory freely.
  * handle target kernel module new attribute cpus_allowed_list
  * fix "This _Backstore already exists in configFS" exception
  * Check whether the enable attribute exists before fread
  * Filter fabric wwns by reading driver name
  * Add support of efct fabric driver
  * tcmu: add support for config param data_pages_per_blk
  * Relax restrictions on TPG Tag range
  * rtslib: Use O_RDWR for sg devices alone.
* Sun Jan 30 2022 mgolub@suse.com
- Update parameters description in rbd-support.patch
- Add rbd-support-disable_emulate_legacy_capacity.patch (bsc#1199090)
* Thu Sep 30 2021 schubi@suse.de
- Use libalternatives instead of update-alternatives.
* Sat Nov  7 2020 lduncan@suse.com
- Fixed issue in SPEC file w/r/t package split with common.
  Now, packages python3-rtslib-fb and python-rtslib-fb-common
  are built, and the former depends on the latter. The common
  package has the non-python parts (documentation, etc),
  and the python3-* part the python parts.
* Fri Oct 23 2020 lduncan@suse.com
- Split package into "common" part, python-rtslib-fb-common, which
  is python-verserion-agnostic, and either python2-rtslib-comon-fb
  or python3-rtslib-fb. This maens common files, like man pages,
  don't have to be duplicated.
* Fri Oct 16 2020 lduncan@suse.com
- Update to version v2.1.74:
  * version 2.1.74
  * rtslib: safely call shutil.copy()
  * Fix fail when target_core_mod doesn't exists
  * Fix EPERM errors with scsi_generic devices
  Also, add this commit submitted upstream:
  * rtslib-Fix-handling-of-sysfs-RW-attrs-that-are-actually-RO.patch
  And this commit for SUSE:
  * rtslib-target-service-for-suse.patch
  Lastly, this package now installs systemd unit file target.service,
  which will replace eventually targetcli.service (from the
  targetcli-fb package), since this matches how upstream works.
  This also meant updating the SPEC file.
* Thu Aug 27 2020 moliver@suse.com
- Updated the rbd-support.patch (bsc#1175808):
  * Fixed the signiture of the RBDStorageObject to match changes made
    to parent StorageObject class.
* Tue Jun 30 2020 lduncan@suse.com
- Update to version v2.1.73 (bsc#1173257 CVE-2020-14019):
  * version 2.1.73
  * save_to_file: fix fd open mode
  * saveconfig: copy temp configfile with permissions
  * saveconfig: open the temp configfile with modes set
  * Fix "is not" with a literal SyntaxWarning
  * Fix an incorrect config path in two comments
  * version 2.1.72
  * Do not change dbroot after drivers have been registered
  * Remove '_if_needed' from RTSRoot._set_dbroot()'s name
  Replacing old tarball with python-rtslib-fb-v2.1.73.tar.xz
* Tue Mar  3 2020 lduncan@suse.com
- Update to version v2.1.71 (jre#SLE-7751):
  * version 2.1.71
  * restoreconfig: fix skipping of targets [re]loading
  Replacing python-rtslib-fb-v2.1.70.tar.xz with python-rtslib-fb-v2.1.71.tar.xz
* Mon Sep 16 2019 lduncan@suse.com
- Update to version v2.1.70:
  * version 2.1.70
  * restoreconfig: add ability to restore/reload single target or storage_object
  * rtslib: fix __version__
  * saveconfig: add hw_block_size support in control string
  * remove extra semicolons in _get_saveconf
  * Add 'readable' param to Group list_*() methods
  * Handle write-only parameters like attributes
  * save_to_file() function breaks symbolic link when saving configuration
  * Handle write-only attributes.
  * Allow bs_cache to be bypassed
  * report the correct size for partitions
  * restoreconfig: support restore when list is non-empty
  Replacing python-rtslib-fb-2.1.69.tar.xz with python-rtslib-fb-v2.1.70.tar.xz,
  and removing patches:
  * 0001-Handle-write-only-attributes.patch
  * 0002-Handle-write-only-parameters-like-attributes.patch
  * 0003-Add-readable-param-to-Group-list_-methods.patch
* Mon Feb 18 2019 lduncan@suse.com
- Added 3 patches subbmitted and accepted upstream, to deal with
  possibly-write-only sysfs attributes (bsc#1123933), adding:
  * 0001-Handle-write-only-attributes.patch
  * 0002-Handle-write-only-parameters-like-attributes.patch
  * 0003-Add-readable-param-to-Group-list_-methods.patch
* Fri Dec  7 2018 ddiss@suse.com
- Enable RBD support for SLE/Leap 15+ (bsc#1118516)
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Thu Oct 18 2018 opensuse-packaging@opensuse.org
- Update to version 2.1.69:
  * version 2.1.fb69
  * fix compiler warning
  * version 2.1.fb68
  * Fix typo
  * - remove underscore in hostname
  * tcm: allow to enable asynchronous I/O for file backing stores
  * saveconfig: way for block-level save with delete command
  * saveconfig: fix missing import
  * saveconfig: handle no attr exception in _parse_info()
  * saveconfig: fix failure in absence of save file
  * saveconfig: dump control string containing control=value tuples
  * restoreconfig: fix alua tpg config setup
  * tcmu: add control constructor arg
  * save_to_file: support saveconfig at storage object level
  * Allow creating more than 256 LUNs per target
  * Ship a systemd service file
  Which replaces python-rtslib-fb-2.1.67.tar.xz with
  python-rtslib-fb-2.1.69.tar.xz, and updates the SPEC file as well.
* Tue Apr 10 2018 ddiss@suse.com
- Merge RBD support from non-fb version (bsc#1079329)
  + rbd-support.patch (SLE/Leap only, due to LIO kernel dependency)
  + Add explicit Provides for "python-rtslib-rbd"
* Tue Apr 10 2018 ddiss@suse.com
- Automatically generate version string from upstream tag
  + Retain current fb-removed version format used
  + Rename rtslib-fb-2.1.fb67.tar.xz to python-rtslib-fb-2.1.67.tar.xz and
    cleanup hardcoded duplicate name/version values in spec
* Mon Apr  9 2018 lduncan@suse.com
- Update to version 2.1.fb67:
  * Add missing dependency on six in setup.py
  * Display a more meaningful error when targetcli cannot change "dbroot"
  * Raise an error about failing to change the dbroot value only if the directory does not exist
  * More compatibility syntax for legacy distros
  * Remove hba-only directories in clear_existing()
  * Correct name for Xen pvscsi
  * version 2.1.fb65
  * Fix unqualified reference to pyudev.Device
  * version 2.1.fb66
  * create: remove stale hba-only dir
  * version 2.1.fb67
- This replaced rtslib-fb-2.1.fb64.tar.xz with
  rtslib-fb-2.1.fb67.tar.xz, and it also removed
  the patch correct-name-for-xen-pvscsi.patch,
  since it is already in the updated tarball
* Sun Feb 25 2018 olaf@aepfle.de
- Fix upgrade path by provide/obsolete python-rtslib (bsc#1082693)
* Wed Jan 24 2018 lduncan@suse.com
- Fix incorrect naming for XEN (bsc#1076455), adding patch:
  * correct-name-for-xen-pvscsi.patch
* Tue Jan  9 2018 tchvatal@suse.com
- Fix the conflict to the rtslib properly
* Wed Jan  3 2018 tchvatal@suse.com
- Drop the epydoc dependency/documentation generating from the package
  to allow building in py3 only enviroment
* Sun Dec 10 2017 lduncan@suse.com
- Converting RPM SPEC file to singlespec format (bsc#1045332),
  updating SPEC file only.
- ran 'spec-cleaner' on SPEC file to clean it up.
- Converted from manually-added rtslib-fb-2.1.fb64.tar.gz to
  tar_scm service-retrieved rtslib-fb-2.1.fb64.tar.xz
* Thu Aug 17 2017 lszhu@suse.com
- Update to version 2.1.fb64
  * Improve ALUA and TCMU support, as well as moving the default
  directory for APTPL files from /var/target to /etc/target
  for better FHS compliance.
  * Remove patch Switch-target-driver-DB-root-dir-to-etc-target.patch
  from the spec file because upstream already has this change.
* Thu Jun  8 2017 lduncan@suse.com
- Enable Persistent Reservations (bsc#1042944):
  * Add patch Switch-target-driver-DB-root-dir-to-etc-target.patch
  * Add /etc/target/pr and /etc/target/alua to SPEC file
* Thu Apr 13 2017 hare@suse.com
- Update to version 2.1.63 (bsc#1032833):
  * Get/Set LUN's ALUA group
  * Add ALUA restore support
  * Delete ALUA groups with its storage object
  * version 2.1.fb62
  * Do not set alua_tg_pt_gp if not supported
  * Add ability to invalidate caches
  * Add ALUA supported method
  * Don't raise exception when getting/setting a LUNs ALUA group
  * update to 2.1.fb63
* Fri Jun 24 2016 lduncan@suse.com
- Updated spec file: Removed Provides/Obsoletes for python-rtslib,
  and added Conflicts for same (bsc#986475)
* Tue Jun 14 2016 lduncan@suse.com
- Fixing build issue: removed 'noarch' from main package
* Tue Jun 14 2016 lduncan@suse.com
- Updated SPEC file:
  * added Requires for pyudev (bsc#984563)
  * removed BuildRequires of pyudev for doc sub-package
* Wed Apr 20 2016 lduncan@suse.com
- Update to version 2.1.fb60
  * no changelog available, but git log shows 59 changes,
    some trivial
* Tue May 12 2015 benoit.monin@gmx.fr
- update to version 2.1.51:
  * no changelog available
* Wed Sep  3 2014 dmueller@suse.com
- update to 2.1.49:
  * Improve error message when NetworkPortal restore fails
  * Python 3.x porting fixes
  * targetctl: A missing restore file is not an error
  * Add a message if no configfile is found
  * Add StorageObjectFactory
  * Convert all exceptions in set_parameter/attribute to RTSLibError
  * Change set_parameters/attributes to take an err_func
  * Fix missing err_func parameter to set_attributes
  * '!' allowed character in block and partition names
  * Don't add to cache if cfs create fails
  * Don't lower-case return values from _parse_info functions
* Tue Jan 14 2014 speilicke@suse.com
- Conflict with python-rtslib
* Mon Jan 13 2014 dmueller@suse.com
- update to 2.1.43:
  * various bugfixes
* Mon Oct 28 2013 dmueller@suse.com
- Initial package (2.1.40)
